@@ -4,8 +4,15 @@ Generic Functional Group
 
 """
 
+
+from __future__ import annotations
+
+from typing import TypeVar
+
 from .functional_group import FunctionalGroup
 
+_T = TypeVar('_T', bound='GenericFunctionalGroup')
+
 
 class GenericFunctionalGroup(FunctionalGroup):
     """
@@ -60,14 +67,35 @@ class GenericFunctionalGroup(FunctionalGroup):
         clone._deleters = self._deleters
         return clone
 
-    def _with_atoms(self, atom_map):
-        super()._with_atoms(atom_map)
-        self._bonders = tuple(
+    def with_atoms(self, atom_map):
+        clone = super().with_atoms(atom_map)
+        clone.__class__ = GenericFunctionalGroup
+        clone._bonders = tuple(
             atom_map.get(a.get_id(), a) for a in self._bonders
         )
-        self._deleters = tuple(
+        clone._deleters = tuple(
             atom_map.get(a.get_id(), a) for a in self._deleters
         )
+        return clone
+
+    def _with_ids(self: _T, id_map: dict[int, int]) -> _T:
+        super()._with_ids(id_map)
+        self._bonders = tuple(
+            bonder.with_id(
+                id=id_map.get(
+                    bonder.get_id(),
+                    bonder.get_id(),
+                )
+            ) for bonder in self._bonders
+        )
+        self._deleters = tuple(
+            deleter.with_id(
+                id=id_map.get(
+                    deleter.get_id(),
+                    deleter.get_id(),
+                ),
+            ) for deleter in self._deleters
+        )
         return self
 
     def get_bonders(self):
