@@ -6,16 +6,92 @@ Hexagonal
 
 import numpy as np
 
-
-from .cof import Cof
-from .vertices import _LinearCofVertex, _NonLinearCofVertex
 from ..topology_graph import Edge
+from .cof import Cof
+from .vertices import LinearVertex, NonLinearVertex
 
 
 class Hexagonal(Cof):
     """
     Represents a hexagonal COF topology graph.
 
+    Unoptimized construction
+
+    .. moldoc::
+
+        import moldoc.molecule as molecule
+        import stk
+
+        bb1 = stk.BuildingBlock('BrCCBr', [stk.BromoFactory()])
+        bb2 = stk.BuildingBlock(
+            smiles='Brc1c(Br)c(Br)c(Br)c(Br)c1Br',
+            functional_groups=[stk.BromoFactory()],
+        )
+
+        cof = stk.ConstructedMolecule(
+            topology_graph=stk.cof.Hexagonal(
+                building_blocks=(bb1, bb2),
+                lattice_size=(2, 2, 1),
+            ),
+        )
+        moldoc_display_molecule = molecule.Molecule(
+            atoms=(
+                molecule.Atom(
+                    atomic_number=atom.get_atomic_number(),
+                    position=position,
+                ) for atom, position in zip(
+                    cof.get_atoms(),
+                    cof.get_position_matrix(),
+                )
+            ),
+            bonds=(
+                molecule.Bond(
+                    atom1_id=bond.get_atom1().get_id(),
+                    atom2_id=bond.get_atom2().get_id(),
+                    order=bond.get_order(),
+                ) for bond in cof.get_bonds()
+            ),
+        )
+
+    ``Collapser(scale_steps=False)`` optimized construction
+
+    .. moldoc::
+
+        import moldoc.molecule as molecule
+        import stk
+
+        bb1 = stk.BuildingBlock('BrCCBr', [stk.BromoFactory()])
+        bb2 = stk.BuildingBlock(
+            smiles='Brc1c(Br)c(Br)c(Br)c(Br)c1Br',
+            functional_groups=[stk.BromoFactory()],
+        )
+
+        cof = stk.ConstructedMolecule(
+            topology_graph=stk.cof.Hexagonal(
+                building_blocks=(bb1, bb2),
+                lattice_size=(2, 2, 1),
+                optimizer=stk.Collapser(scale_steps=False),
+            ),
+        )
+        moldoc_display_molecule = molecule.Molecule(
+            atoms=(
+                molecule.Atom(
+                    atomic_number=atom.get_atomic_number(),
+                    position=position,
+                ) for atom, position in zip(
+                    cof.get_atoms(),
+                    cof.get_position_matrix(),
+                )
+            ),
+            bonds=(
+                molecule.Bond(
+                    atom1_id=bond.get_atom1().get_id(),
+                    atom2_id=bond.get_atom2().get_id(),
+                    order=bond.get_order(),
+                ) for bond in cof.get_bonds()
+            ),
+        )
+
     Building blocks with six and two functional groups are required
     for this topology graph.
 
@@ -38,74 +114,74 @@ class Hexagonal(Cof):
         np.array([0, 0, 5/1.7321])
     )
 
-    _vertex_prototypes = (
-        _NonLinearCofVertex(0, (1/4)*_a + (1/4)*_b + (1/2)*_c),
-        _NonLinearCofVertex(1, (1/4)*_a + (3/4)*_b + (1/2)*_c),
-        _NonLinearCofVertex(2, (3/4)*_a + (1/4)*_b + (1/2)*_c),
-        _NonLinearCofVertex(3, (3/4)*_a + (3/4)*_b + (1/2)*_c),
+    _non_linears = (
+        NonLinearVertex(0, (1/4)*_a + (1/4)*_b + (1/2)*_c),
+        NonLinearVertex(1, (1/4)*_a + (3/4)*_b + (1/2)*_c),
+        NonLinearVertex(2, (3/4)*_a + (1/4)*_b + (1/2)*_c),
+        NonLinearVertex(3, (3/4)*_a + (3/4)*_b + (1/2)*_c),
     )
 
     _vertex_prototypes = (
-        *_vertex_prototypes,
-        _LinearCofVertex.init_at_center(
+        *_non_linears,
+        LinearVertex.init_at_center(
             id=4,
-            vertices=(_vertex_prototypes[0], _vertex_prototypes[1]),
+            vertices=(_non_linears[0], _non_linears[1]),
         ),
-        _LinearCofVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=5,
-            vertices=(_vertex_prototypes[0], _vertex_prototypes[2]),
+            vertices=(_non_linears[0], _non_linears[2]),
         ),
-        _LinearCofVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=6,
-            vertices=(_vertex_prototypes[1], _vertex_prototypes[2]),
+            vertices=(_non_linears[1], _non_linears[2]),
         ),
-        _LinearCofVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=7,
-            vertices=(_vertex_prototypes[1], _vertex_prototypes[3]),
+            vertices=(_non_linears[1], _non_linears[3]),
         ),
-        _LinearCofVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=8,
-            vertices=(_vertex_prototypes[2], _vertex_prototypes[3]),
+            vertices=(_non_linears[2], _non_linears[3]),
         ),
-        _LinearCofVertex.init_at_shifted_center(
+        LinearVertex.init_at_shifted_center(
             id=9,
-            vertices=(_vertex_prototypes[0], _vertex_prototypes[2]),
+            vertices=(_non_linears[0], _non_linears[2]),
             cell_shifts=((0, 0, 0), (-1, 0, 0)),
             lattice_constants=_lattice_constants,
         ),
-        _LinearCofVertex.init_at_shifted_center(
+        LinearVertex.init_at_shifted_center(
             id=10,
-            vertices=(_vertex_prototypes[0], _vertex_prototypes[1]),
+            vertices=(_non_linears[0], _non_linears[1]),
             cell_shifts=((0, 0, 0), (0, -1, 0)),
             lattice_constants=_lattice_constants,
         ),
-        _LinearCofVertex.init_at_shifted_center(
+        LinearVertex.init_at_shifted_center(
             id=11,
-            vertices=(_vertex_prototypes[0], _vertex_prototypes[3]),
+            vertices=(_non_linears[0], _non_linears[3]),
             cell_shifts=((0, 0, 0), (0, -1, 0)),
             lattice_constants=_lattice_constants,
         ),
-        _LinearCofVertex.init_at_shifted_center(
+        LinearVertex.init_at_shifted_center(
             id=12,
-            vertices=(_vertex_prototypes[2], _vertex_prototypes[1]),
+            vertices=(_non_linears[2], _non_linears[1]),
             cell_shifts=((0, 0, 0), (1, -1, 0)),
             lattice_constants=_lattice_constants,
         ),
-        _LinearCofVertex.init_at_shifted_center(
+        LinearVertex.init_at_shifted_center(
             id=13,
-            vertices=(_vertex_prototypes[2], _vertex_prototypes[3]),
+            vertices=(_non_linears[2], _non_linears[3]),
             cell_shifts=((0, 0, 0), (0, -1, 0)),
             lattice_constants=_lattice_constants,
         ),
-        _LinearCofVertex.init_at_shifted_center(
+        LinearVertex.init_at_shifted_center(
             id=14,
-            vertices=(_vertex_prototypes[1], _vertex_prototypes[3]),
+            vertices=(_non_linears[1], _non_linears[3]),
             cell_shifts=((0, 0, 0), (-1, 0, 0)),
             lattice_constants=_lattice_constants,
         ),
-        _LinearCofVertex.init_at_shifted_center(
+        LinearVertex.init_at_shifted_center(
             id=15,
-            vertices=(_vertex_prototypes[3], _vertex_prototypes[0]),
+            vertices=(_non_linears[3], _non_linears[0]),
             cell_shifts=((0, 0, 0), (1, 0, 0)),
             lattice_constants=_lattice_constants,
         )
