@@ -16,6 +16,9 @@ periodic_collapser\
 
     MCHammer <\
 stk.molecular.topology_graphs.topology_graph.optimizers.mchammer\
+>
+    Spinner <\
+stk.molecular.topology_graphs.topology_graph.optimizers.spinner\
 >
 
     NullOptimizer <\
